.. _tut:

Tutorials and application demos
==================================

The following are instructive demos of using FINUFFT for a variety of
spectrally-related tasks arising in
scientific computing and signal/image processing. We will slowly grow the
list (contact us to add one).
For conciseness of code, and ease of writing, they are currently
in MATLAB (they should work on versions at least back to R2017a).

.. toctree::

   tutorial/serieseval
   tutorial/contft
   tutorial/peripois2d
   tutorial/grf
   tutorial/inv1d2

For further applications, see :ref:`references <refs>`, and:

* These software tutorial `PDF slides <http://users.flatironinstitute.org/~ahb/talks/fwam23.pdf>`_.

* These seminar `PDF slides <http://users.flatironinstitute.org/~ahb/talks/pacm20.pdf>`_.

* `Fast Fresnel diffraction <https://github.com/ahbarnett/fresnaq>`_ for optics and acoustics applications.

* `Equispaced Fourier methods for Gaussian process regression <https://github.com/flatironinstitute/gp-shootout>`_ as described in https://arxiv.org/abs/2210.10210 and https://arxiv.org/abs/2305.11065
  
* Tutorials for PyNUFFT with 1D and 2D reconstruction examples `here <http://jyhmiinlin.github.io/pynufft/tutor/init.html>`_.
     
* The numerical sampling of `random plane waves <https://users.flatironinstitute.org/~ahb/rpws/>`_.

